@@ -1,14 +1,8 @@
 # -*- coding: utf-8 -*-
-import json
-from urllib import urlencode
-from datetime import timedelta, datetime
 
-import requests
 from pagador.seguranca import autenticador
 from pagador.seguranca.autenticador import TipoAutenticacao
-from pagador.seguranca.instalacao import Parametros, InstalacaoNaoFinalizada
-from pagador.settings import MERCADOPAGO_REDIRECT_URL
-import pagador_mercadopago
+from pagador.seguranca.instalacao import Parametros
 
 
 class ParametrosPayPal(Parametros):
@@ -26,7 +20,7 @@ class Credenciador(autenticador.Credenciador):
     def __init__(self, configuracao):
         self.conta_id = configuracao.conta_id
         self.usuario = getattr(configuracao, "usuario", "")
-        self.tipo = TipoAutenticacao.query_string
+        self.tipo = TipoAutenticacao.form_urlencode
 
     @property
     def chave(self):
